###
# Copyright (c) 2021, Pratyush Desai
# All rights reserved.
#
# Redistribution and use in source and binary forms, with or without
# modification, are permitted provided that the following conditions are met:
#
#   * Redistributions of source code must retain the above copyright notice,
#     this list of conditions, and the following disclaimer.
#   * Redistributions in binary form must reproduce the above copyright notice,
#     this list of conditions, and the following disclaimer in the
#     documentation and/or other materials provided with the distribution.
#   * Neither the name of the author of this software nor the name of
#     contributors to this software may be used to endorse or promote products
#     derived from this software without specific prior written consent.
#
# THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
# AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
# IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
# ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
# LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
# CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
# SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
# INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
# CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
# ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
# POSSIBILITY OF SUCH DAMAGE.

###

from supybot import utils, plugins, ircutils, callbacks
from supybot.commands import *
try:
    from supybot.i18n import PluginInternationalization
    _ = PluginInternationalization('DoseLogs')
except ImportError:
    # Placeholder that allows to run the plugin on a bot
    # without the i18n module
    _ = lambda x: x

import os
import sqlite3

class SqliteDoselogsDB(object):
    def __init__(self, filename):
        self.db = {}
        self.filename = filename

    def close(self):
        self.db.close()

    def _getDb(self):
        filename = os.path.basename(self.__class__.__name__)
        if filename in self.db:
            return self.db[filename]
        if os.path.exists(filename):
            db = sqlite3.connect(filename, check_same_thread=False)
            self.db[filename] = db
            return db
        db = sqlite3.connect(filename, check_same_thread=False)
        self.db[filename] = db
        cursor = db.cursor()
        cursor.execute("""CREATE TABLE doselogs (
                        id INTEGER PRIMARY KEY,
                        username TEXT,
                        nick TEXT,
                        timezone TEXT,
                        amount TEXT,
                        drug TEXT,
                        roa TEXT,
                        timestamp TEXT
                        )
        
                        """)


class DoseLogs(callbacks.Plugin):
    """Log and annotate your doses"""
    threaded = True

Class = DoseLogs


# vim:set shiftwidth=4 softtabstop=4 expandtab textwidth=79:
